==> KarsTS_1.0.tar.gz: KarsTS/R/packagesToImport.R <==
packagesToImport <-
function() {
    #' @importFrom circular circular windrose
    #' @importFrom BaylorEdPsych LittleMCAR
    #' @importFrom MVN uniNorm hzTest mardiaTest
    #' @importFrom graphics abline axis curve hist legend lines par plot points
    #' @importFrom utils capture.output globalVariables read.table write.table
    #' @importFrom tcltk tklabel tkmessageBox tkwait.window tktext ttklabel
    #' @importFrom tcltk ttkframe tkscrollbar tkpack tkgrid tkgrid.configure
    #' @importFrom tcltk tkgrid.columnconfigure tkgrid.rowconfigure tkframe 
    #' @importFrom tcltk tkinsert tkfocus tkraise tkfont.create tkdestroy 
    #' @importFrom tcltk tkconfigure tkget tkradiobutton tkbind tclvalue
    #' @importFrom tcltk tkpager tkwinfo tk_choose.dir tkcheckbutton
    #' @importFrom tcltk tcl tkbutton tkwm.title tktoplevel tclVar
    #' @importFrom tcltk2 tk2entry tk2label
    #' @importFrom tkrplot tkrplot tkrreplot
    #' @importFrom tseriesChaos embedd false.nearest mutual plot.false.nearest
    #' @importFrom stlplus stlplus
    #' @importFrom tseries adf.test kpss.test
    #' @importFrom forecast Arima auto.arima
    #' @import stinepack
    #' @importFrom missForest missForest 
    #' @importFrom nonlinearTseries corrDim corrMatrix estimateEmbeddingDim
    #' @importFrom nonlinearTseries nonlinearityTest radius  sampleEntropy 
    #' @importFrom nonlinearTseries surrogateTest timeAsymmetry2
    #' @importFrom stats acf aggregate Box.test ccf coefficients complete.cases
    #' @importFrom stats dnorm IQR KalmanSmooth lm lm.influence 
    #' @importFrom stats loess mad median pacf
    #' @importFrom stats PP.test prcomp predict quantile rnorm sd smooth.spline
    #' @importFrom stats loess.control na.exclude na.pass pf ts confint cor
    #' @importFrom zoo na.approx na.spline rollapply
    #' @importFrom grDevices dev.new
    #' @importFrom rgl plot3d
    #' @importFrom mgcv te gam 
    
}

==> KarsTS_2.0.tar.gz: KarsTS/R/packagesToImport.R <==
packagesToImport <-
function() {
    #' @importFrom circular circular windrose
    #' @importFrom BaylorEdPsych LittleMCAR
    #' @importFrom MVN uniNorm hzTest mardiaTest
    #' @importFrom graphics abline axis curve hist 
    #' @importFrom graphics legend lines par plot points axTicks title
    #' @importFrom utils capture.output globalVariables read.table write.table
    #' @importFrom tcltk tklabel tkmessageBox tkwait.window tktext ttklabel
    #' @importFrom tcltk ttkframe tkscrollbar tkpack tkgrid tkgrid.configure
    #' @importFrom tcltk tkgrid.columnconfigure tkgrid.rowconfigure tkframe 
    #' @importFrom tcltk tkinsert tkfocus tkraise tkfont.create tkdestroy 
    #' @importFrom tcltk tkconfigure tkget tkradiobutton tkbind tclvalue
    #' @importFrom tcltk tkpager tkwinfo tk_choose.dir tkcheckbutton
    #' @importFrom tcltk tcl tkbutton tkwm.title tktoplevel tclVar
    #' @importFrom tcltk2 tk2entry tk2label
    #' @importFrom tkrplot tkrplot tkrreplot
    #' @importFrom tseriesChaos embedd false.nearest mutual plot.false.nearest
    #' @importFrom stlplus stlplus
    #' @importFrom tseries adf.test kpss.test
    #' @importFrom forecast Arima auto.arima
    #' @import stinepack
    #' @importFrom missForest missForest 
    #' @importFrom nonlinearTseries corrDim corrMatrix estimateEmbeddingDim
    #' @importFrom nonlinearTseries nonlinearityTest radius  sampleEntropy 
    #' @importFrom nonlinearTseries surrogateTest timeAsymmetry2
    #' @importFrom stats acf aggregate Box.test ccf coefficients complete.cases
    #' @importFrom stats dnorm IQR KalmanSmooth lm lm.influence time
    #' @importFrom stats loess mad median pacf na.omit
    #' @importFrom stats PP.test prcomp predict quantile rnorm sd smooth.spline
    #' @importFrom stats loess.control na.exclude na.pass pf ts confint cor
    #' @importFrom zoo na.approx na.spline rollapply
    #' @importFrom grDevices dev.new
    #' @importFrom rgl plot3d
    #' @importFrom mgcv te gam
    #' @importFrom infotheo discretize mutinformation
    #' @importFrom plot3D image2D 
    
}
